Introduction
============

Requirements
------------

asyncakinator requires Python 3.9 and above. Support for previous versions of Python is not supported.

Dependencies
------------

* `aiohttp <https://pypi.org/project/aiohttp/>`_

Usually, ``pip`` will install the dependencies for you.


Installing
----------
This installs the latest stable release of asyncakinator from `PyPI <https://pypi.org/project/asyncakinator>`_ .

.. tab:: Windows

    .. code-block:: console

        py -3 -m pip install -U asyncakinator

.. tab:: MacOS/Linux

    .. code-block:: console

        python3 -m pip install asyncakinator

Installing Development Versions
-------------------------------
If you want to install the development version of asyncakinator, follow the directions below.

.. caution::

    The development version of asyncakinator is not garantueed to be stable. It may contain bugs and/or breaking changes.

.. tab:: Windows

    .. code-block:: console

        py -3 -m pip install -U git+https://github.com/avizum/asyncakinator@main

.. tab:: MacOS/Linux

    .. code-block:: console

        python3 -m pip install -U git+https://github.com/avizum/asyncakinator@main